@@ -7,10 +7,12 @@ import (
 	"os"
 	"path/filepath"
 	"reflect"
+	"strings"
 
 	"github.com/barasher/go-exiftool"
 	"github.com/pelletier/go-toml/v2"
 	varibale "github.com/yorukot/superfile/src/config"
+	"github.com/yorukot/superfile/src/config/icon"
 )
 
 func initialConfig(dir string) (toggleDotFileBool bool, firstFilePanelDir string) {
@@ -27,6 +29,8 @@ func initialConfig(dir string) (toggleDotFileBool bool, firstFilePanelDir string
 
 	loadThemeFile()
 
+	icon.InitIcon(Config.Nerdfont)
+
 	toggleDotFileData, err := os.ReadFile(varibale.ToggleDotFilea)
 	if err != nil {
 		outPutLog("Error while reading toggleDotFile data error:", err)
@@ -45,13 +49,17 @@ func initialConfig(dir string) (toggleDotFileBool bool, firstFilePanelDir string
 		}
 	}
 
-	firstFilePanelDir = varibale.HomeDir
 	if dir != "" {
 		firstFilePanelDir, err = filepath.Abs(dir)
-		if err != nil {
-			firstFilePanelDir = varibale.HomeDir
-		}
+	} else {
+		Config.DefaultDirectory = strings.Replace(Config.DefaultDirectory, "~", varibale.HomeDir, -1) 
+		firstFilePanelDir, err = filepath.Abs(Config.DefaultDirectory)
 	}
+
+	if err != nil {
+		firstFilePanelDir = varibale.HomeDir
+	}
+
 	return toggleDotFileBool, firstFilePanelDir
 }
 
@@ -121,6 +129,25 @@ func loadHotkeysFile() {
 		}
 	}
 
+	val := reflect.ValueOf(hotkeys)
+
+	for i := 0; i < val.NumField(); i++ {
+		field := val.Type().Field(i)
+		value := val.Field(i)
+
+		if value.Kind() != reflect.Slice || value.Type().Elem().Kind() != reflect.String {
+			fmt.Println(lodaHotkeysError(field.Name))
+			os.Exit(0)
+		}
+
+		hotkeysList := value.Interface().([]string)
+
+		if len(hotkeysList) == 0  || hotkeysList[0] == "" {
+			fmt.Println(lodaHotkeysError(field.Name))
+			os.Exit(0)
+		}
+	}
+   
 }
 
 func loadThemeFile() {
