@@ -84,7 +84,7 @@ func getHelpMenuData() []helpMenuModalData {
 		{
 			subTitle: "Panel navigation",
 		},
-		{
+	{
 			hotkey:         hotkeys.CreateNewFilePanel,
 			description:    "Create new file panel",
 			hotkeyWorkType: globalType,
@@ -177,11 +177,6 @@ func getHelpMenuData() []helpMenuModalData {
 			description:    "Pin or Unpin folder to sidebar (can be auto saved)",
 			hotkeyWorkType: globalType,
 		},
-		{
-			hotkey:         hotkeys.ToggleDotFile,
-			description:    "Toggle to show dotfiles or not",
-			hotkeyWorkType: globalType,
-		},
 		{
 			subTitle: "File operations",
 		},
@@ -201,7 +196,7 @@ func getHelpMenuData() []helpMenuModalData {
 			hotkeyWorkType: globalType,
 		},
 		{
-			hotkey:         hotkeys.PasteItems,
+			hotkey:         hotkeys.CutItems,
 			description:    "Cut selected items to the clipboard",
 			hotkeyWorkType: globalType,
 		},
@@ -211,7 +206,7 @@ func getHelpMenuData() []helpMenuModalData {
 			hotkeyWorkType: globalType,
 		},
 		{
-			hotkey:         hotkeys.PasteItems,
+			hotkey:         hotkeys.DeleteItems,
 			description:    "Delete selected items",
 			hotkeyWorkType: globalType,
 		},
