@@ -1,6 +1,8 @@
 package internal
 
 import (
+	"crypto/md5"
+	"encoding/hex"
 	"fmt"
 	"io"
 	"log"
@@ -12,9 +14,9 @@ import (
 	"strings"
 	"time"
 
-	"github.com/charmbracelet/bubbles/textinput"
 	"github.com/lithammer/shortuuid"
-	"github.com/masatana/go-textdistance"
+	"github.com/reinhrst/fzf-lib"
+	"github.com/yorukot/superfile/src/config/icon"
 )
 
 // Check if the directory is external disk path
@@ -45,11 +47,11 @@ func returnFolderElement(location string, displayDotFile bool) (directoryElement
 	if len(files) == 0 {
 		return directoryElement
 	}
-	
+
 	if err != nil {
 		outPutLog("Return folder element function error", err)
 	}
-	
+
 	sort.Slice(files, func(i, j int) bool {
 		if files[i].IsDir() && !files[j].IsDir() {
 			return true
@@ -94,27 +96,45 @@ func returnFolderElementBySearchString(location string, displayDotFile bool, sea
 		outPutLog("Return folder element function error", err)
 	}
 
+	folderElementMap := map[string]element{}
+	fileAndDirectories := []string{}
+
 	for _, item := range items {
 		fileInfo, _ := item.Info()
 		if !displayDotFile && strings.HasPrefix(fileInfo.Name(), ".") {
 			continue
 		}
+
 		if fileInfo == nil {
 			continue
 		}
-		newElement := element{
+
+		folderElementLocation := location + "/" + item.Name()
+		if location == "/" {
+			folderElementLocation = location + item.Name()
+		}
+
+		fileAndDirectories = append(fileAndDirectories, item.Name())
+		folderElementMap[item.Name()] = element{
 			name:      item.Name(),
 			directory: item.IsDir(),
-			matchRate: textdistance.JaroWinklerDistance(item.Name(), searchString),
-		}
-		if location == "/" {
-			newElement.location = location + item.Name()
-		} else {
-			newElement.location = location + "/" + item.Name()
-		}
-		if newElement.matchRate > 0 {
-			folderElement = append(folderElement, newElement)
+			location:  folderElementLocation,
 		}
+
+	}
+
+	var options = fzf.DefaultOptions()
+	var hayStack = fileAndDirectories
+	var myFzf = fzf.New(hayStack, options)
+	var result fzf.SearchResult
+	myFzf.Search(searchString)
+	result = <-myFzf.GetResultChannel()
+	myFzf.End()
+
+	for _, item := range result.Matches {
+		resultItem := folderElementMap[item.Key]
+		resultItem.matchRate = float64(item.Score)
+		folderElement = append(folderElement, resultItem)
 	}
 
 	// Sort folders and files by match rate
@@ -245,15 +265,15 @@ func pasteFile(src string, dst string) error {
 	return nil
 }
 
-func returnMetaData(m model) model {
+func (m *model) returnMetaData() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	cursor := panel.cursor
 	id := shortuuid.New()
 
 	message := channelMessage{
-		messageId:    id,
-		messageType:  sendMetadata,
-		metadata:     m.fileMetaData.metaData,
+		messageId:   id,
+		messageType: sendMetadata,
+		metadata:    m.fileMetaData.metaData,
 	}
 
 	// Obtaining metadata will take time. If metadata is obtained for every passing file, it will cause lag.
@@ -262,20 +282,20 @@ func returnMetaData(m model) model {
 	time.Sleep(150 * time.Millisecond)
 
 	if LastTimeCursorMove[1] != cursor && m.focusPanel != metadataFocus {
-		return m
+		return
 	}
 
 	m.fileMetaData.metaData = m.fileMetaData.metaData[:0]
 	if len(panel.element) == 0 {
-		message.metadata = m.fileMetaData.metaData 
+		message.metadata = m.fileMetaData.metaData
 		channel <- message
-		return m
+		return
 	}
 	if len(panel.element[panel.cursor].metaData) != 0 && m.focusPanel != metadataFocus {
 		m.fileMetaData.metaData = panel.element[panel.cursor].metaData
-		message.metadata = m.fileMetaData.metaData 
+		message.metadata = m.fileMetaData.metaData
 		channel <- message
-		return m
+		return
 	}
 	filePath := panel.element[panel.cursor].location
 
@@ -287,9 +307,9 @@ func returnMetaData(m model) model {
 		} else {
 			m.fileMetaData.metaData = append(m.fileMetaData.metaData, [2]string{"This is a link file.", ""})
 		}
-		message.metadata = m.fileMetaData.metaData 
+		message.metadata = m.fileMetaData.metaData
 		channel <- message
-		return m
+		return
 
 	}
 
@@ -303,15 +323,16 @@ func returnMetaData(m model) model {
 			m.fileMetaData.metaData = append(m.fileMetaData.metaData, [2]string{"FolderSize", formatFileSize(dirSize(filePath))})
 		}
 		m.fileMetaData.metaData = append(m.fileMetaData.metaData, [2]string{"FolderModifyDate", fileInfo.ModTime().String()})
-		message.metadata = m.fileMetaData.metaData 
+		m.fileMetaData.metaData = append(m.fileMetaData.metaData, [2]string{"FolderPermissions", fileInfo.Mode().String()})
+		message.metadata = m.fileMetaData.metaData
 		channel <- message
-		return m
+		return
 	}
 
 	checkIsSymlinked, err := os.Lstat(filePath)
 	if err != nil {
 		outPutLog("err when getting file info", err)
-		return m
+		return
 	}
 
 	if Config.Metadata && checkIsSymlinked.Mode()&os.ModeSymlink == 0 {
@@ -333,14 +354,42 @@ func returnMetaData(m model) model {
 		fileName := [2]string{"FileName", fileInfo.Name()}
 		fileSize := [2]string{"FileSize", formatFileSize(fileInfo.Size())}
 		fileModifyData := [2]string{"FileModifyDate", fileInfo.ModTime().String()}
-		m.fileMetaData.metaData = append(m.fileMetaData.metaData, fileName, fileSize, fileModifyData)
+		filePermissions := [2]string{"FilePermissions", fileInfo.Mode().String()}
+
+		if Config.EnableMD5Checksum {
+			// Calculate MD5 checksum
+			checksum, err := calculateMD5Checksum(filePath)
+			if err != nil {
+				outPutLog("Error calculating MD5 checksum", err)
+			} else {
+				md5Data := [2]string{"MD5Checksum", checksum}
+				m.fileMetaData.metaData = append(m.fileMetaData.metaData, md5Data)
+			}
+		}
+
+		m.fileMetaData.metaData = append(m.fileMetaData.metaData, fileName, fileSize, fileModifyData, filePermissions)
 	}
 
-	message.metadata = m.fileMetaData.metaData 
+	message.metadata = m.fileMetaData.metaData
 	channel <- message
 
 	panel.element[panel.cursor].metaData = m.fileMetaData.metaData
-	return m
+}
+
+func calculateMD5Checksum(filePath string) (string, error) {
+	file, err := os.Open(filePath)
+	if err != nil {
+		return "", fmt.Errorf("failed to open file: %v", err)
+	}
+	defer file.Close()
+
+	hash := md5.New()
+	if _, err := io.Copy(hash, file); err != nil {
+		return "", fmt.Errorf("failed to calculate MD5 checksum: %v", err)
+	}
+
+	checksum := hex.EncodeToString(hash.Sum(nil))
+	return checksum, nil
 }
 
 // Get directory total size
@@ -375,21 +424,6 @@ func countFiles(dirPath string) (int, error) {
 	return count, err
 }
 
-// Generate search bar for file panel
-func generateSearchBar() textinput.Model {
-	ti := textinput.New()
-	ti.Cursor.Style = footerCursorStyle
-	ti.Cursor.TextStyle = footerStyle
-	ti.TextStyle = filePanelStyle
-	ti.Prompt = filePanelTopDirectoryIconStyle.Render(" ")
-	ti.Cursor.Blink = true
-	ti.PlaceholderStyle = filePanelStyle
-	ti.Placeholder = "(" + hotkeys.SearchBar[0] + ") Type something"
-	ti.Blur()
-	ti.CharLimit = 156
-	return ti
-}
-
 // Check whether is broken recursive symlinks
 func isBrokenSymlink(filePath string) bool {
 	linkPath, err := os.Readlink(filePath)
@@ -433,3 +467,59 @@ func isImageFile(filename string) bool {
 	ext := strings.ToLower(filepath.Ext(filename))
 	return imageExtensions[ext]
 }
+
+func getElementIcon(file string, IsDir bool) icon.IconStyle {
+	ext := strings.TrimPrefix(filepath.Ext(file), ".")
+	name := file
+
+	if !Config.Nerdfont {
+		return icon.IconStyle{
+			Icon:  "",
+			Color: theme.FilePanelFG,
+		}
+	}
+
+	if IsDir {
+		resultIcon := icon.Folders["folder"]
+		betterIcon, hasBetterIcon := icon.Folders[name]
+		if hasBetterIcon {
+			resultIcon = betterIcon
+		}
+		return resultIcon
+	} else {
+		// default icon for all files. try to find a better one though...
+		resultIcon := icon.Icons["file"]
+		// resolve aliased extensions
+		extKey := strings.ToLower(ext)
+		alias, hasAlias := icon.Aliases[extKey]
+		if hasAlias {
+			extKey = alias
+		}
+
+		// see if we can find a better icon based on extension alone
+		betterIcon, hasBetterIcon := icon.Icons[extKey]
+		if hasBetterIcon {
+			resultIcon = betterIcon
+		}
+
+		// now look for icons based on full names
+		fullName := name
+
+		fullName = strings.ToLower(fullName)
+		fullAlias, hasFullAlias := icon.Aliases[fullName]
+		if hasFullAlias {
+			fullName = fullAlias
+		}
+		bestIcon, hasBestIcon := icon.Icons[fullName]
+		if hasBestIcon {
+			resultIcon = bestIcon
+		}
+		if resultIcon.Color == "NONE" {
+			return icon.IconStyle{
+				Icon:  resultIcon.Icon,
+				Color: theme.FilePanelFG,
+			}
+		}
+		return resultIcon
+	}
+}
