@@ -13,10 +13,11 @@ import (
 	"github.com/charmbracelet/bubbles/textinput"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/lithammer/shortuuid"
+	"github.com/yorukot/superfile/src/config/icon"
 )
 
 // Create a file in the currently focus file panel
-func panelCreateNewFile(m model) model {
+func (m *model) panelCreateNewFile() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	ti := textinput.New()
 	ti.Cursor.Style = modalCursorStyle
@@ -36,18 +37,18 @@ func panelCreateNewFile(m model) model {
 
 	m.fileModel.filePanels[m.filePanelFocusIndex] = panel
 
-	return m
 }
 
 // Rename file where the cusror is located
-func panelItemRename(m model) model {
+func (m *model) panelItemRename() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	if len(panel.element) == 0 {
-		return m
+		return
 	}
 	ti := textinput.New()
 	ti.Cursor.Style = filePanelCursorStyle
 	ti.Cursor.TextStyle = filePanelStyle
+	ti.Prompt = filePanelCursorStyle.Render(icon.Cursor + " ")
 	ti.TextStyle = modalStyle
 	ti.Cursor.Blink = true
 	ti.Placeholder = "New name"
@@ -62,18 +63,17 @@ func panelItemRename(m model) model {
 	m.firstTextInput = true
 	panel.rename = ti
 	m.fileModel.filePanels[m.filePanelFocusIndex] = panel
-	return m
 }
 
-func deleteItemWarn(m model) model {
+func (m *model) deleteItemWarn() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	if !((panel.panelMode == selectMode && len(panel.selected) != 0) || (panel.panelMode == browserMode)) {
-		return m
+		return
 	}
 	id := shortuuid.New()
 	message := channelMessage{
-		messageId:       id,
-		messageType:  snedWarnModal,
+		messageId:   id,
+		messageType: snedWarnModal,
 	}
 
 	if isExternalDiskPath(panel.location) {
@@ -84,7 +84,7 @@ func deleteItemWarn(m model) model {
 			warnType: confirmDeleteItem,
 		}
 		channel <- message
-		return m
+		return
 	} else {
 		message.warnModal = warnModal{
 			open:     true,
@@ -93,24 +93,24 @@ func deleteItemWarn(m model) model {
 			warnType: confirmDeleteItem,
 		}
 		channel <- message
-		return m
+		return
 	}
 }
 
 // Move file or directory to the trash can
-func deleteSingleItem(m model) model {
+func (m *model) deleteSingleItem() {
 	id := shortuuid.New()
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 
 	if len(panel.element) == 0 {
-		return m
+		return
 	}
 
 	prog := progress.New(generateGradientColor())
 	prog.PercentageStyle = footerStyle
 
 	newProcess := process{
-		name:     "󰆴 " + panel.element[panel.cursor].name,
+		name:     icon.Delete + icon.Space + panel.element[panel.cursor].name,
 		progress: prog,
 		state:    inOperation,
 		total:    1,
@@ -119,8 +119,8 @@ func deleteSingleItem(m model) model {
 	m.processBarModel.process[id] = newProcess
 
 	message := channelMessage{
-		messageId: id,
-		messageType: sendProcess,
+		messageId:       id,
+		messageType:     sendProcess,
 		processNewState: newProcess,
 	}
 
@@ -144,11 +144,10 @@ func deleteSingleItem(m model) model {
 		panel.cursor--
 	}
 	m.fileModel.filePanels[m.filePanelFocusIndex] = panel
-	return m
 }
 
 // Move file or directory to the trash can
-func deleteMultipleItems(m model) {
+func (m model) deleteMultipleItems() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	if len(panel.selected) != 0 {
 		id := shortuuid.New()
@@ -156,7 +155,7 @@ func deleteMultipleItems(m model) {
 		prog.PercentageStyle = footerStyle
 
 		newProcess := process{
-			name:     "󰆴 " + filepath.Base(panel.selected[0]),
+			name:     icon.Delete + icon.Space + filepath.Base(panel.selected[0]),
 			progress: prog,
 			state:    inOperation,
 			total:    len(panel.selected),
@@ -166,8 +165,8 @@ func deleteMultipleItems(m model) {
 		m.processBarModel.process[id] = newProcess
 
 		message := channelMessage{
-			messageId: id,
-			messageType: sendProcess,
+			messageId:       id,
+			messageType:     sendProcess,
 			processNewState: newProcess,
 		}
 
@@ -176,7 +175,7 @@ func deleteMultipleItems(m model) {
 		for _, filePath := range panel.selected {
 
 			p := m.processBarModel.process[id]
-			p.name = "󰆴 " + filepath.Base(filePath)
+			p.name = icon.Delete + icon.Space + filepath.Base(filePath)
 			p.done++
 			p.state = inOperation
 			if len(channel) < 5 {
@@ -213,12 +212,12 @@ func deleteMultipleItems(m model) {
 }
 
 // Completely delete file or folder (Not move to the trash can)
-func completelyDeleteSingleItem(m model) model {
+func (m *model) completelyDeleteSingleItem() {
 	id := shortuuid.New()
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 
 	if len(panel.element) == 0 {
-		return m
+		return
 	}
 
 	prog := progress.New(generateGradientColor())
@@ -234,11 +233,11 @@ func completelyDeleteSingleItem(m model) model {
 	m.processBarModel.process[id] = newProcess
 
 	message := channelMessage{
-		messageId: id,
-		messageType: sendProcess,
+		messageId:       id,
+		messageType:     sendProcess,
 		processNewState: newProcess,
 	}
-	
+
 	channel <- message
 
 	err := os.RemoveAll(panel.element[panel.cursor].location)
@@ -263,11 +262,10 @@ func completelyDeleteSingleItem(m model) model {
 		panel.cursor--
 	}
 	m.fileModel.filePanels[m.filePanelFocusIndex] = panel
-	return m
 }
 
 // Completely delete all file or folder from clipboard (Not move to the trash can)
-func completelyDeleteMultipleItems(m model) {
+func (m model) completelyDeleteMultipleItems() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	if len(panel.selected) != 0 {
 		id := shortuuid.New()
@@ -275,7 +273,7 @@ func completelyDeleteMultipleItems(m model) {
 		prog.PercentageStyle = footerStyle
 
 		newProcess := process{
-			name:     "󰆴 " + filepath.Base(panel.selected[0]),
+			name:     icon.Delete + icon.Space + filepath.Base(panel.selected[0]),
 			progress: prog,
 			state:    inOperation,
 			total:    len(panel.selected),
@@ -285,8 +283,8 @@ func completelyDeleteMultipleItems(m model) {
 		m.processBarModel.process[id] = newProcess
 
 		message := channelMessage{
-			messageId:  id,
-			messageType: sendProcess,
+			messageId:       id,
+			messageType:     sendProcess,
 			processNewState: newProcess,
 		}
 
@@ -294,7 +292,7 @@ func completelyDeleteMultipleItems(m model) {
 		for _, filePath := range panel.selected {
 
 			p := m.processBarModel.process[id]
-			p.name = "󰆴 " + filepath.Base(filePath)
+			p.name = icon.Delete + icon.Space + filepath.Base(filePath)
 			p.done++
 			p.state = inOperation
 			if len(channel) < 5 {
@@ -334,18 +332,18 @@ func completelyDeleteMultipleItems(m model) {
 }
 
 // Copy directory or file
-func copySingleItem(m model) model {
+func (m *model) copySingleItem() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	m.copyItems.cut = false
 	m.copyItems.items = m.copyItems.items[:0]
 	if len(panel.element) == 0 {
-		return m
+		return
 	}
 	m.copyItems.items = append(m.copyItems.items, panel.element[panel.cursor].location)
 	fileInfo, err := os.Stat(panel.element[panel.cursor].location)
 	if os.IsNotExist(err) {
 		m.copyItems.items = m.copyItems.items[:0]
-		return m
+		return
 	}
 	if err != nil {
 		outPutLog("Copy single item get file state error", panel.element[panel.cursor].location, err)
@@ -363,21 +361,20 @@ func copySingleItem(m model) model {
 		}
 	}
 	m.fileModel.filePanels[m.filePanelFocusIndex] = panel
-	return m
 }
 
 // Copy all selected file or directory to the clipboard
-func copyMultipleItem(m model) model {
+func (m *model) copyMultipleItem() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	m.copyItems.cut = false
 	m.copyItems.items = m.copyItems.items[:0]
 	if len(panel.selected) == 0 {
-		return m
+		return
 	}
 	m.copyItems.items = panel.selected
 	fileInfo, err := os.Stat(panel.selected[0])
 	if os.IsNotExist(err) {
-		return m
+		return
 	}
 	if err != nil {
 		outPutLog("Copy multiple item function get file state error", panel.selected[0], err)
@@ -395,22 +392,21 @@ func copyMultipleItem(m model) model {
 		}
 	}
 	m.fileModel.filePanels[m.filePanelFocusIndex] = panel
-	return m
 }
 
 // Cut directory or file
-func cutSingleItem(m model) model {
+func (m *model) cutSingleItem() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	m.copyItems.cut = true
 	m.copyItems.items = m.copyItems.items[:0]
 	if len(panel.element) == 0 {
-		return m
+		return
 	}
 	m.copyItems.items = append(m.copyItems.items, panel.element[panel.cursor].location)
 	fileInfo, err := os.Stat(panel.element[panel.cursor].location)
 	if os.IsNotExist(err) {
 		m.copyItems.items = m.copyItems.items[:0]
-		return m
+		return
 	}
 	if err != nil {
 		outPutLog("Cut single item get file state error", panel.element[panel.cursor].location, err)
@@ -428,21 +424,20 @@ func cutSingleItem(m model) model {
 		}
 	}
 	m.fileModel.filePanels[m.filePanelFocusIndex] = panel
-	return m
 }
 
 // Cut all selected file or directory to the clipboard
-func cutMultipleItem(m model) model {
+func (m *model) cutMultipleItem() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	m.copyItems.cut = true
 	m.copyItems.items = m.copyItems.items[:0]
 	if len(panel.selected) == 0 {
-		return m
+		return
 	}
 	m.copyItems.items = panel.selected
 	fileInfo, err := os.Stat(panel.selected[0])
 	if os.IsNotExist(err) {
-		return m
+		return
 	}
 	if err != nil {
 		outPutLog("Copy multiple item function get file state error", panel.selected[0], err)
@@ -460,16 +455,15 @@ func cutMultipleItem(m model) model {
 		}
 	}
 	m.fileModel.filePanels[m.filePanelFocusIndex] = panel
-	return m
 }
 
 // Paste all clipboard items
-func pasteItem(m model) {
+func (m model) pasteItem() {
 	id := shortuuid.New()
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 
 	if len(m.copyItems.items) == 0 {
-		return 
+		return
 	}
 
 	totalFiles := 0
@@ -485,9 +479,9 @@ func pasteItem(m model) {
 	prog := progress.New(generateGradientColor())
 	prog.PercentageStyle = footerStyle
 
-	prefixIcon := "󰆏 "
+	prefixIcon := icon.Copy + icon.Space
 	if m.copyItems.cut {
-		prefixIcon = "󰆐 "
+		prefixIcon = icon.Cut + icon.Space
 	}
 
 	newProcess := process{
@@ -501,8 +495,8 @@ func pasteItem(m model) {
 	m.processBarModel.process[id] = newProcess
 
 	message := channelMessage{
-		messageId: id,
-		messageType: sendProcess,
+		messageId:       id,
+		messageType:     sendProcess,
 		processNewState: newProcess,
 	}
 
@@ -512,12 +506,12 @@ func pasteItem(m model) {
 	for _, filePath := range m.copyItems.items {
 		var err error
 		if m.copyItems.cut && !isExternalDiskPath(filePath) {
-			p.name = "󰆐 " + filepath.Base(filePath)
+			p.name = icon.Cut + icon.Space + filepath.Base(filePath)
 		} else {
 			if m.copyItems.cut {
-				p.name = "󰆐 " + filepath.Base(filePath)
+				p.name = icon.Cut + icon.Space + filepath.Base(filePath)
 			}
-			p.name = "󰆏 " + filepath.Base(filePath)
+			p.name = icon.Copy + icon.Space + filepath.Base(filePath)
 		}
 
 		errMessage := "cut item error"
@@ -555,7 +549,7 @@ func pasteItem(m model) {
 }
 
 // Extrach compress file
-func extractFile(m model) {
+func (m model) extractFile() {
 	var err error
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	ext := strings.ToLower(filepath.Ext(panel.element[panel.cursor].location))
@@ -583,7 +577,7 @@ func extractFile(m model) {
 }
 
 // Compress file or directory
-func compressFile(m model) {
+func (m model) compressFile() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	fileName := filepath.Base(panel.element[panel.cursor].location)
 
@@ -598,11 +592,10 @@ func compressFile(m model) {
 }
 
 // Open file with default editor
-func openFileWithEditor(m model) tea.Cmd {
+func (m model) openFileWithEditor() tea.Cmd {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 
 	editor := os.Getenv("EDITOR")
-	m.editorMode = true
 	if editor == "" {
 		editor = "nano"
 	}
@@ -614,9 +607,8 @@ func openFileWithEditor(m model) tea.Cmd {
 }
 
 // Open directory with default editor
-func openDirectoryWithEditor(m model) tea.Cmd {
+func (m model) openDirectoryWithEditor() tea.Cmd {
 	editor := os.Getenv("EDITOR")
-	m.editorMode = true
 	if editor == "" {
 		editor = "nano"
 	}
