@@ -2,60 +2,57 @@ package internal
 
 import (
 	"os"
+	"os/exec"
 	"path/filepath"
 	"strings"
 )
 
 // Cancel typing modal e.g. create file or directory
-func cancelTypingModal(m model) model {
+func (m *model) cancelTypingModal() {
 	m.typingModal.textInput.Blur()
 	m.typingModal.open = false
-	return m
 }
 
 // Close warn modal
-func cancelWarnModal(m model) model {
+func (m *model) cancelWarnModal() {
 	m.warnModal.open = false
-	return m
 }
 
 // Confirm to create file or directory
-func createItem(m model) model {
+func (m *model) createItem() {
 	if !strings.HasSuffix(m.typingModal.textInput.Value(), "/") {
 		path := filepath.Join(m.typingModal.location, m.typingModal.textInput.Value())
 		path, _ = renameIfDuplicate(path)
 		if err := os.MkdirAll(filepath.Dir(path), 0755); err != nil {
-			outPutLog("Create item function error", err)
+			outPutLog("Create item func (m *model)tion error", err)
 		}
 		f, err := os.Create(path)
 		if err != nil {
-			outPutLog("Create item function create file error", err)
+			outPutLog("Create item func (m *model)tion create file error", err)
 		}
 		defer f.Close()
 	} else {
 		path := m.typingModal.location + "/" + m.typingModal.textInput.Value()
 		err := os.MkdirAll(path, 0755)
 		if err != nil {
-			outPutLog("Create item function create folder error", err)
+			outPutLog("Create item func (m *model)tion create folder error", err)
 		}
 	}
 	m.typingModal.open = false
 	m.typingModal.textInput.Blur()
-	return m
 }
 
 // Cancel rename file or directory
-func cancelReanem(m model) model {
+func (m *model) cancelReanem() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	panel.rename.Blur()
 	panel.renaming = false
 	m.fileModel.renaming = false
 	m.fileModel.filePanels[m.filePanelFocusIndex] = panel
-	return m
 }
 
 // Connfirm rename file or directory
-func confirmRename(m model) model {
+func (m *model) confirmRename() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	oldPath := panel.element[panel.cursor].location
 	newPath := panel.location + "/" + panel.rename.Value()
@@ -63,35 +60,32 @@ func confirmRename(m model) model {
 	// Rename the file
 	err := os.Rename(oldPath, newPath)
 	if err != nil {
-		outPutLog("Confirm function rename error", err)
+		outPutLog("Confirm func (m *model)tion rename error", err)
 	}
 
 	m.fileModel.renaming = false
 	panel.rename.Blur()
 	panel.renaming = false
 	m.fileModel.filePanels[m.filePanelFocusIndex] = panel
-	return m
 }
 
 // Cancel search, this will clear all searchbar input
-func cancelSearch(m model) model {
+func (m *model) cancelSearch() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	panel.searchBar.Blur()
 	panel.searchBar.SetValue("")
 	m.fileModel.filePanels[m.filePanelFocusIndex] = panel
-	return m
 }
 
 // Confirm search
-func confirmSearch(m model) model {
+func (m *model) confirmSearch() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	panel.searchBar.Blur()
 	m.fileModel.filePanels[m.filePanelFocusIndex] = panel
-	return m
 }
 
 // Help menu panel list up
-func helpMenuListUp(m model) model {
+func (m *model) helpMenuListUp() {
 	if m.helpMenu.cursor > 1 {
 		m.helpMenu.cursor--
 		if m.helpMenu.cursor < m.helpMenu.renderIndex {
@@ -108,13 +102,12 @@ func helpMenuListUp(m model) model {
 		m.helpMenu.renderIndex = len(m.helpMenu.data) - m.helpMenu.height
 	}
 
-	return m
 }
 
 // Help menu panel list down
-func helpMenuListDown(m model) model {
+func (m *model) helpMenuListDown() {
 	if len(m.helpMenu.data) == 0 {
-		return m
+		return
 	}
 
 	if m.helpMenu.cursor < len(m.helpMenu.data)-1 {
@@ -133,11 +126,45 @@ func helpMenuListDown(m model) model {
 		m.helpMenu.renderIndex = 0
 	}
 
-	return m
+}
+
+// Toggle help menu
+func (m *model) openHelpMenu() {
+	if m.helpMenu.open {
+		m.helpMenu.open = false
+		return
+	}
+
+	m.helpMenu.open = true
 }
 
 // Quit help menu
-func quitHelpMenu(m model) model {
+func (m *model) quitHelpMenu() {
 	m.helpMenu.open = false
-	return m
 }
+
+// Command line
+func (m *model) openCommandLine() {
+	m.firstTextInput = true
+	footerHeight--
+	m.commandLine.input = generateCommandLineInputBox()
+	m.commandLine.input.Width = m.fullWidth - 3
+	m.commandLine.input.Focus()
+}
+
+func (m *model) closeCommandLine() {
+	footerHeight++
+	m.commandLine.input.SetValue("")
+	m.commandLine.input.Blur()
+}
+
+func (m *model) enterCommandLine() {
+	cmd := exec.Command("/bin/sh", "-c", m.commandLine.input.Value())
+	// 执行命令并获取输出
+	_, err := cmd.CombinedOutput()
+	if err != nil {
+		outPutLog("Error run command line command", err)
+		return
+	}
+	m.commandLine.input.SetValue("")
+}
\ No newline at end of file
