@@ -8,7 +8,7 @@ import (
 )
 
 // Pinned directory
-func pinnedDirectory(m model) model {
+func (m *model) pinnedDirectory() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 
 	unPinned := false
@@ -45,13 +45,12 @@ func pinnedDirectory(m model) model {
 	}
 
 	m.fileModel.filePanels[m.filePanelFocusIndex] = panel
-	return m
 }
 
 // Create new file panel
-func createNewFilePanel(m model) model {
+func (m *model) createNewFilePanel() {
 	if len(m.fileModel.filePanels) == m.fileModel.maxFilePanel {
-		return m
+		return
 	}
 
 	m.fileModel.filePanels = append(m.fileModel.filePanels, filePanel{
@@ -81,13 +80,12 @@ func createNewFilePanel(m model) model {
 	for i := range m.fileModel.filePanels {
 		m.fileModel.filePanels[i].searchBar.Width = m.fileModel.width - 4
 	}
-	return m
 }
 
 // Close current focus file panel
-func closeFilePanel(m model) model {
+func (m *model) closeFilePanel() {
 	if len(m.fileModel.filePanels) == 1 {
-		return m
+		return
 	}
 
 	m.fileModel.filePanels = append(m.fileModel.filePanels[:m.filePanelFocusIndex], m.fileModel.filePanels[m.filePanelFocusIndex+1:]...)
@@ -114,10 +112,9 @@ func closeFilePanel(m model) model {
 	for i := range m.fileModel.filePanels {
 		m.fileModel.filePanels[i].searchBar.Width = m.fileModel.width - 4
 	}
-	return m
 }
 
-func toggleFilePreviewPanel(m model) model {
+func (m *model) toggleFilePreviewPanel() {
 	m.fileModel.filePreview.open = !m.fileModel.filePreview.open
 	m.fileModel.filePreview.width = 0
 	if m.fileModel.filePreview.open {
@@ -137,11 +134,10 @@ func toggleFilePreviewPanel(m model) model {
 		m.fileModel.filePanels[i].searchBar.Width = m.fileModel.width - 4
 	}
 
-	return m
 }
 
 // Focus on next file panel
-func nextFilePanel(m model) model {
+func (m *model) nextFilePanel() {
 	m.fileModel.filePanels[m.filePanelFocusIndex].focusType = noneFocus
 	if m.filePanelFocusIndex == (len(m.fileModel.filePanels) - 1) {
 		m.filePanelFocusIndex = 0
@@ -150,11 +146,10 @@ func nextFilePanel(m model) model {
 	}
 
 	m.fileModel.filePanels[m.filePanelFocusIndex].focusType = returnFocusType(m.focusPanel)
-	return m
 }
 
 // Focus on previous file panel
-func previousFilePanel(m model) model {
+func (m *model) previousFilePanel() {
 	m.fileModel.filePanels[m.filePanelFocusIndex].focusType = noneFocus
 	if m.filePanelFocusIndex == 0 {
 		m.filePanelFocusIndex = (len(m.fileModel.filePanels) - 1)
@@ -163,13 +158,12 @@ func previousFilePanel(m model) model {
 	}
 
 	m.fileModel.filePanels[m.filePanelFocusIndex].focusType = returnFocusType(m.focusPanel)
-	return m
 }
 
 // Focus on sidebar
-func focusOnSideBar(m model) model {
+func (m *model) focusOnSideBar() {
 	if Config.SidebarWidth == 0 {
-		return m
+		return
 	}
 	if m.focusPanel == sidebarFocus {
 		m.focusPanel = nonePanelFocus
@@ -178,11 +172,10 @@ func focusOnSideBar(m model) model {
 		m.focusPanel = sidebarFocus
 		m.fileModel.filePanels[m.filePanelFocusIndex].focusType = secondFocus
 	}
-	return m
 }
 
 // Focus on processbar
-func focusOnProcessBar(m model) model {
+func (m *model) focusOnProcessBar() {
 	if m.focusPanel == processBarFocus {
 		m.focusPanel = nonePanelFocus
 		m.fileModel.filePanels[m.filePanelFocusIndex].focusType = focus
@@ -190,11 +183,10 @@ func focusOnProcessBar(m model) model {
 		m.focusPanel = processBarFocus
 		m.fileModel.filePanels[m.filePanelFocusIndex].focusType = secondFocus
 	}
-	return m
 }
 
 // focus on metadata
-func focusOnMetadata(m model) model {
+func (m *model) focusOnMetadata() {
 	if m.focusPanel == metadataFocus {
 		m.focusPanel = nonePanelFocus
 		m.fileModel.filePanels[m.filePanelFocusIndex].focusType = focus
@@ -202,5 +194,4 @@ func focusOnMetadata(m model) model {
 		m.focusPanel = metadataFocus
 		m.fileModel.filePanels[m.filePanelFocusIndex].focusType = secondFocus
 	}
-	return m
 }
