@@ -4,6 +4,7 @@ import (
 	"log"
 	"os"
 	"path/filepath"
+	"strings"
 	"time"
 
 	"github.com/barasher/go-exiftool"
@@ -94,6 +95,10 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			footerHeight = 14
 		}
 
+		if m.commandLine.input.Focused() {
+			footerHeight--
+		}
+
 		m.mainPanelHeight = msg.Height - footerHeight + 1
 
 		// set help menu size
@@ -121,35 +126,40 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		}
 
 		if m.typingModal.open {
-			m = typingModalOpenKey(msg.String(), m)
+			m.typingModalOpenKey(msg.String())
 		} else if m.warnModal.open {
-			m = warnModalOpenKey(msg.String(), m)
+			m.warnModalOpenKey(msg.String())
 		} else if m.fileModel.renaming {
-			m = renamingKey(msg.String(), m)
+			m.renamingKey(msg.String())
 		} else if panel.searchBar.Focused() {
-			m = focusOnSearchbarKey(msg.String(), m)
+			m.focusOnSearchbarKey(msg.String())
 		} else if m.helpMenu.open {
-			m = helpMenuKey(msg.String(), m)
+			m.helpMenuKey(msg.String())
+		} else if m.commandLine.input.Focused() {
+			m.commandLineKey(msg.String())
+		} else if m.confirmToQuit {
+			quit := m.confirmToQuitSuperfile(msg.String())
+			if quit {
+				m.quitSuperfile()
+				return m, tea.Quit
+			}
 		} else {
 			// return superfile
-			if msg.String() == hotkeys.Quit[0] || msg.String() == hotkeys.Quit[1] {
-				// cd on quit
-				if Config.CdOnQuit {
-					currentDir := m.fileModel.filePanels[m.filePanelFocusIndex].location
-					if currentDir == varibale.HomeDir {
-						return m, tea.Quit
+			if msg.String() == containsKey(msg.String(), hotkeys.Quit) {
+				for _, data := range m.processBarModel.process {
+					if data.state == inOperation && data.done != data.total {
+						m.confirmToQuit = true
+						m.warnModal.title = "Confirm to quit superfile"
+						m.warnModal.content = "You still have files being processed. Are you sure you want to exit?"
+						return m, cmd
 					}
-					os.WriteFile(varibale.SuperFileStateDir+"/lastdir", []byte("cd "+currentDir), 0755)
 				}
+
+				m.quitSuperfile()
 				return m, tea.Quit
 			}
 
-			m, cmd = mainKey(msg.String(), m, cmd)
-
-			if m.editorMode {
-				m.editorMode = false
-				return m, cmd
-			}
+			cmd = m.mainKey(msg.String(), cmd)
 		}
 	}
 
@@ -159,6 +169,8 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		m.fileModel.filePanels[m.filePanelFocusIndex].rename, cmd = m.fileModel.filePanels[m.filePanelFocusIndex].rename.Update(msg)
 	} else if panel.searchBar.Focused() {
 		m.fileModel.filePanels[m.filePanelFocusIndex].searchBar, cmd = m.fileModel.filePanels[m.filePanelFocusIndex].searchBar.Update(msg)
+	} else if m.commandLine.input.Focused() {
+		m.commandLine.input, cmd =  m.commandLine.input.Update(msg)
 	} else if m.typingModal.open {
 		m.typingModal.textInput, cmd = m.typingModal.textInput.Update(msg)
 	}
@@ -175,7 +187,7 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		cmd = tea.Batch(cmd, listenForChannelMessage(channel))
 	}
 
-	m = getFilePanelItems(m)
+	m.getFilePanelItems()
 
 	return m, tea.Batch(cmd)
 }
@@ -183,53 +195,66 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 func (m model) View() string {
 	// check is the terminal size enough
 	if m.fullHeight < minimumHeight || m.fullWidth < minimumWidth {
-		return terminalSizeWarnRender(m)
+		return m.terminalSizeWarnRender()
 	}
 	if m.fileModel.width < 18 {
-		return terminalSizeWarnAfterFirstRender(m)
+		return m.terminalSizeWarnAfterFirstRender()
 	}
-	sidebar := sidebarRender(m)
+	sidebar := m.sidebarRender()
 
-	filePanel := filePanelRender(m)
+	filePanel := m.filePanelRender()
 
-	filePreview := filePreviewPanelRender(m)
+	filePreview := m.filePreviewPanelRender()
 
 	mainPanel := lipgloss.JoinHorizontal(0, sidebar, filePanel, filePreview)
 
-	processBar := processBarRender(m)
+	processBar := m.processBarRender()
 
-	metaData := metadataRender(m)
+	metaData := m.metadataRender()
+
+	clipboardBar := m.clipboardRender()
 
-	clipboardBar := clipboardRender(m)
 
 	footer := lipgloss.JoinHorizontal(0, processBar, metaData, clipboardBar)
 
+	if m.commandLine.input.Focused() {
+		commandLine := m.commandLineInputBoxRender()
+		footer = lipgloss.JoinVertical(0, footer, commandLine)
+	}
+
 	finalRender := lipgloss.JoinVertical(0, mainPanel, footer)
 
 	// check if need pop up modal
 	if m.helpMenu.open {
-		helpMenu := helpMenuRender(m)
+		helpMenu := m.helpMenuRender()
 		overlayX := m.fullWidth/2 - m.helpMenu.width/2
 		overlayY := m.fullHeight/2 - m.helpMenu.height/2
 		return stringfunction.PlaceOverlay(overlayX, overlayY, helpMenu, finalRender)
 	}
 
 	if firstUse {
-		introduceModal := introduceModalRender(m)
+		introduceModal := m.introduceModalRender()
 		overlayX := m.fullWidth/2 - m.helpMenu.width/2
 		overlayY := m.fullHeight/2 - m.helpMenu.height/2
 		return stringfunction.PlaceOverlay(overlayX, overlayY, introduceModal, finalRender)
 	}
 
 	if m.typingModal.open {
-		typingModal := typineModalRender(m)
+		typingModal := m.typineModalRender()
 		overlayX := m.fullWidth/2 - modalWidth/2
 		overlayY := m.fullHeight/2 - modalHeight/2
 		return stringfunction.PlaceOverlay(overlayX, overlayY, typingModal, finalRender)
 	}
 
 	if m.warnModal.open {
-		warnModal := warnModalRender(m)
+		warnModal := m.warnModalRender()
+		overlayX := m.fullWidth/2 - modalWidth/2
+		overlayY := m.fullHeight/2 - modalHeight/2
+		return stringfunction.PlaceOverlay(overlayX, overlayY, warnModal, finalRender)
+	}
+
+	if m.confirmToQuit {
+		warnModal := m.warnModalRender()
 		overlayX := m.fullWidth/2 - modalWidth/2
 		overlayY := m.fullHeight/2 - modalHeight/2
 		return stringfunction.PlaceOverlay(overlayX, overlayY, warnModal, finalRender)
@@ -255,7 +280,7 @@ func listenForChannelMessage(msg chan channelMessage) tea.Cmd {
 	}
 }
 
-func getFilePanelItems(m model) model {
+func (m *model) getFilePanelItems() {
 	focusPanel := m.fileModel.filePanels[m.filePanelFocusIndex]
 	for i, filePanel := range m.fileModel.filePanels {
 		var fileElenent []element
@@ -289,5 +314,17 @@ func getFilePanelItems(m model) model {
 		m.fileModel.filePanels[i].element = fileElenent
 		m.fileModel.filePanels[i].lastTimeGetElement = nowTime
 	}
-	return m
 }
+
+func (m model) quitSuperfile() {
+	// cd on quit
+	if Config.CdOnQuit {
+		currentDir := m.fileModel.filePanels[m.filePanelFocusIndex].location
+		if currentDir == varibale.HomeDir {
+			return
+		}
+		// escape single quote
+		currentDir = strings.ReplaceAll(currentDir, "'", "'\\''")
+		os.WriteFile(varibale.SuperFileStateDir+"/lastdir", []byte("cd '"+currentDir+"'"), 0755)
+	}
+}
\ No newline at end of file
