@@ -14,14 +14,15 @@ import (
 	"github.com/charmbracelet/lipgloss"
 	"github.com/charmbracelet/x/exp/term/ansi"
 	"github.com/yorukot/ansichroma"
+	"github.com/yorukot/superfile/src/config/icon"
 	filepreview "github.com/yorukot/superfile/src/pkg/file_preview"
 )
 
-func sidebarRender(m model) string {
+func (m model) sidebarRender() string {
 	if Config.SidebarWidth == 0 {
 		return ""
 	}
-	superfileTitle := sidebarTitleStyle.Render("     Super File")
+	superfileTitle := sidebarTitleStyle.Render("    " + icon.SuperfileIcon + " Super File")
 	superfileTitle = ansi.Truncate(superfileTitle, Config.SidebarWidth, "")
 	s := superfileTitle
 	s += "\n"
@@ -59,7 +60,7 @@ func sidebarRender(m model) string {
 		totalHeight++
 		cursor := " "
 		if m.sidebarModel.cursor == i && m.focusPanel == sidebarFocus {
-			cursor = ""
+			cursor = icon.Cursor
 		}
 
 		if directory.location == m.fileModel.filePanels[m.filePanelFocusIndex].location {
@@ -72,7 +73,7 @@ func sidebarRender(m model) string {
 	return sideBarBorderStyle(m.mainPanelHeight, m.focusPanel).Render(s)
 }
 
-func filePanelRender(m model) string {
+func (m model) filePanelRender() string {
 	// file panel
 	f := make([]string, 10)
 	for i, filePanel := range m.fileModel.filePanels {
@@ -84,7 +85,7 @@ func filePanelRender(m model) string {
 		}
 		m.fileModel.filePanels[i] = filePanel
 
-		f[i] += filePanelTopDirectoryIconStyle.Render("   ") + filePanelTopPathStyle.Render(truncateTextBeginning(filePanel.location, m.fileModel.width-4, "...")) + "\n"
+		f[i] += filePanelTopDirectoryIconStyle.Render(" "+icon.Directory+icon.Space) + filePanelTopPathStyle.Render(truncateTextBeginning(filePanel.location, m.fileModel.width-4, "...")) + "\n"
 		filePanelWidth := 0
 		footerBorderWidth := 0
 
@@ -101,15 +102,15 @@ func filePanelRender(m model) string {
 		}
 		panelModeString := ""
 		if filePanel.panelMode == browserMode {
-			panelModeString = "󰈈 Browser"
+			panelModeString = icon.Browser + icon.Space + "Browser"
 		} else if filePanel.panelMode == selectMode {
-			panelModeString = "󰆽 Select"
+			panelModeString = icon.Select + icon.Space + "Select"
 		}
 
 		f[i] += filePanelDividerStyle(filePanel.focusType).Render(strings.Repeat(Config.BorderTop, filePanelWidth)) + "\n"
 		f[i] += " " + filePanel.searchBar.View() + "\n"
 		if len(filePanel.element) == 0 {
-			f[i] += filePanelStyle.Render("   No such file or directory")
+			f[i] += filePanelStyle.Render(" " + icon.Error + "  No such file or directory")
 			bottomBorder := generateFooterBorder(fmt.Sprintf("%s%s%s", panelModeString, bottomMiddleBorderSplit, "0/0"), footerBorderWidth)
 			f[i] = filePanelBorderStyle(m.mainPanelHeight, filePanelWidth, filePanel.focusType, bottomBorder).Render(f[i])
 		} else {
@@ -121,7 +122,7 @@ func filePanelRender(m model) string {
 				cursor := " "
 				// Check if the cursor needs to be displayed, if the user is using the search bar, the cursor is not displayed
 				if h == filePanel.cursor && !filePanel.searchBar.Focused() {
-					cursor = ""
+					cursor = icon.Cursor
 				}
 				isItemSelected := arrayContains(filePanel.selected, filePanel.element[h].location)
 				if filePanel.renaming && h == filePanel.cursor {
@@ -146,7 +147,7 @@ func filePanelRender(m model) string {
 	return filePanelRender
 }
 
-func processBarRender(m model) string {
+func (m model) processBarRender() string {
 	// save process in the array
 	var processes []process
 	for _, p := range m.processBarModel.process {
@@ -196,13 +197,13 @@ func processBarRender(m model) string {
 		}
 		switch process.state {
 		case failure:
-			symbol = processErrorStyle.Render("")
+			symbol = processErrorStyle.Render(icon.Warn)
 		case successful:
-			symbol = processSuccessfulStyle.Render("")
+			symbol = processSuccessfulStyle.Render(icon.Done)
 		case inOperation:
-			symbol = processInOperationStyle.Render("󰥔")
+			symbol = processInOperationStyle.Render(icon.InOperation)
 		case cancel:
-			symbol = processCancelStyle.Render("")
+			symbol = processCancelStyle.Render(icon.Error)
 		}
 
 		processRender += cursor + footerStyle.Render(truncateText(process.name, footerWidth(m.fullWidth)-7, "...")+" ") + symbol + "\n"
@@ -217,7 +218,7 @@ func processBarRender(m model) string {
 	}
 
 	if len(processes) == 0 {
-		processRender += "\n   No processes running"
+		processRender += "\n " + icon.Error + "  No processes running"
 	}
 	courseNumber := 0
 	if len(m.processBarModel.processList) == 0 {
@@ -231,14 +232,14 @@ func processBarRender(m model) string {
 	return processRender
 }
 
-func metadataRender(m model) string {
+func (m model) metadataRender() string {
 	// process bar
 	metaDataBar := ""
 	if len(m.fileMetaData.metaData) == 0 && len(m.fileModel.filePanels[m.filePanelFocusIndex].element) > 0 && !m.fileModel.renaming {
 		m.fileMetaData.metaData = append(m.fileMetaData.metaData, [2]string{"", ""})
-		m.fileMetaData.metaData = append(m.fileMetaData.metaData, [2]string{" 󰥔  Loading metadata...", ""})
+		m.fileMetaData.metaData = append(m.fileMetaData.metaData, [2]string{" " + icon.InOperation + "  Loading metadata...", ""})
 		go func() {
-			m = returnMetaData(m)
+			m.returnMetaData()
 		}()
 	}
 	maxKeyLength := 0
@@ -287,12 +288,12 @@ func metadataRender(m model) string {
 	return metaDataBar
 }
 
-func clipboardRender(m model) string {
+func (m model) clipboardRender() string {
 
 	// render
 	clipboardRender := ""
 	if len(m.copyItems.items) == 0 {
-		clipboardRender += "\n   No content in clipboard"
+		clipboardRender += "\n " + icon.Error + "  No content in clipboard"
 	} else {
 		for i := 0; i < len(m.copyItems.items) && i < bottomElementHeight(footerHeight); i++ {
 			if i == bottomElementHeight(footerHeight)-1 {
@@ -323,7 +324,7 @@ func clipboardRender(m model) string {
 	return clipboardRender
 }
 
-func terminalSizeWarnRender(m model) string {
+func (m model) terminalSizeWarnRender() string {
 	fullWidthString := strconv.Itoa(m.fullWidth)
 	fullHeightString := strconv.Itoa(m.fullHeight)
 	minimumWidthString := strconv.Itoa(minimumWidth)
@@ -347,7 +348,7 @@ func terminalSizeWarnRender(m model) string {
 		heightString + terminalCorrectSize.Render(minimumHeightString))
 }
 
-func terminalSizeWarnAfterFirstRender(m model) string {
+func (m model) terminalSizeWarnAfterFirstRender() string {
 	minimumWidthInt := Config.SidebarWidth + 20*len(m.fileModel.filePanels) + 20 - 1
 	minimumWidthString := strconv.Itoa(minimumWidthInt)
 	fullWidthString := strconv.Itoa(m.fullWidth)
@@ -373,10 +374,10 @@ func terminalSizeWarnAfterFirstRender(m model) string {
 		heightString + terminalCorrectSize.Render(minimumHeightString))
 }
 
-func typineModalRender(m model) string {
+func (m model) typineModalRender() string {
 	previewPath := m.typingModal.location + "/" + m.typingModal.textInput.Value()
 
-	fileLocation := filePanelTopDirectoryIconStyle.Render("   ") +
+	fileLocation := filePanelTopDirectoryIconStyle.Render(" "+icon.Directory+icon.Space) +
 		filePanelTopPathStyle.Render(truncateTextBeginning(previewPath, modalWidth-4, "...")) + "\n"
 
 	confirm := modalConfirm.Render(" (" + hotkeys.ConfirmTyping[0] + ") Create ")
@@ -389,7 +390,7 @@ func typineModalRender(m model) string {
 	return modalBorderStyle(modalHeight, modalWidth).Render(fileLocation + "\n" + m.typingModal.textInput.View() + "\n\n" + tip)
 }
 
-func introduceModalRender(m model) string {
+func (m model) introduceModalRender() string {
 	title := sidebarTitleStyle.Render(" Thanks for use superfile!!") + modalStyle.Render("\n You can read the following information before starting to use it!")
 	vimUserWarn := processErrorStyle.Render("  ** Very importantly ** If you are a Vim/Nvim user, go to:\n  https://superfile.netlify.app/configure/custom-hotkeys/ to change your hotkey settings!")
 	subOne := sidebarTitleStyle.Render("  (1)") + modalStyle.Render(" If this is your first time, make sure you read:\n      https://superfile.netlify.app/getting-started/tutorial/")
@@ -399,7 +400,7 @@ func introduceModalRender(m model) string {
 	return firstUseModal(m.helpMenu.height, m.helpMenu.width).Render(title + "\n\n" + vimUserWarn + "\n\n" + subOne + "\n\n" + subTwo + "\n\n" + subThree + "\n\n" + subFour + "\n\n")
 }
 
-func warnModalRender(m model) string {
+func (m model) warnModalRender() string {
 	title := m.warnModal.title
 	content := m.warnModal.content
 	confirm := modalConfirm.Render(" (" + hotkeys.Confirm[0] + ") Confirm ")
@@ -408,13 +409,18 @@ func warnModalRender(m model) string {
 	return modalBorderStyle(modalHeight, modalWidth).Render(title + "\n\n" + content + "\n\n" + tip)
 }
 
-func helpMenuRender(m model) string {
+func (m model) helpMenuRender() string {
 	helpMenuContent := ""
 	maxKeyLength := 0
 
 	for _, data := range m.helpMenu.data {
-		if data.subTitle == "" && len(data.hotkey[0]+data.hotkey[1])+3 > maxKeyLength {
-			maxKeyLength = len(data.hotkey[0]+data.hotkey[1]) + 3
+		totalKeyLen := 0
+		for _, key := range data.hotkey {
+			totalKeyLen += len(key)
+		}
+		saprateLen := len(data.hotkey) - 1*3
+		if data.subTitle == "" && totalKeyLen+saprateLen > maxKeyLength {
+			maxKeyLength = totalKeyLen + saprateLen
 		}
 	}
 
@@ -443,11 +449,13 @@ func helpMenuRender(m model) string {
 			continue
 		}
 
-		if m.helpMenu.data[i].hotkey[1] == "" {
-			hotkey = m.helpMenu.data[i].hotkey[0]
-		} else {
-			hotkey = fmt.Sprintf("%s | %s", m.helpMenu.data[i].hotkey[0], m.helpMenu.data[i].hotkey[1])
+		for i, key := range m.helpMenu.data[i].hotkey {
+			if i != 0 {
+				hotkey += " | "
+			}
+			hotkey += key
 		}
+
 		if len(helpMenuHotkeyStyle.Render(hotkey)) > renderHotkeyLength {
 			renderHotkeyLength = len(helpMenuHotkeyStyle.Render(hotkey))
 		}
@@ -466,14 +474,17 @@ func helpMenuRender(m model) string {
 
 		hotkey := ""
 		description := truncateText(m.helpMenu.data[i].description, valueLength, "...")
-		if m.helpMenu.data[i].hotkey[1] == "" {
-			hotkey = m.helpMenu.data[i].hotkey[0]
-		} else {
-			hotkey = fmt.Sprintf("%s | %s", m.helpMenu.data[i].hotkey[0], m.helpMenu.data[i].hotkey[1])
+
+		for i, key := range m.helpMenu.data[i].hotkey {
+			if i != 0 {
+				hotkey += " | "
+			}
+			hotkey += key
 		}
+
 		cursor := "  "
 		if m.helpMenu.cursor == i {
-			cursor = filePanelCursorStyle.Render(" ")
+			cursor = filePanelCursorStyle.Render(icon.Cursor + " ")
 		}
 		helpMenuContent += cursor + modalStyle.Render(fmt.Sprintf("%*s%s", renderHotkeyLength, helpMenuHotkeyStyle.Render(hotkey+" "), modalStyle.Render(description)))
 	}
@@ -483,7 +494,7 @@ func helpMenuRender(m model) string {
 	return helpMenuModalBorderStyle(m.helpMenu.height, m.helpMenu.width, bottomBorder).Render(helpMenuContent)
 }
 
-func filePreviewPanelRender(m model) string {
+func (m model) filePreviewPanelRender() string {
 	previewLine := m.mainPanelHeight + 2
 	m.fileModel.filePreview.width += m.fullWidth - Config.SidebarWidth - m.fileModel.filePreview.width - ((m.fileModel.width + 2) * len(m.fileModel.filePanels)) - 2
 
@@ -491,16 +502,24 @@ func filePreviewPanelRender(m model) string {
 	box := filePreviewBox(previewLine, m.fileModel.filePreview.width)
 
 	if len(panel.element) == 0 {
-		return box.Render("\n ---  No content to preview ---")
+		return box.Render("\n --- " + icon.Error + " No content to preview ---")
 	}
 
 	itemPath := panel.element[panel.cursor].location
 
 	fileInfo, err := os.Stat(itemPath)
+
 	if err != nil {
 		outPutLog("error get file info", err)
-		return box.Render("\n ---  Error get file info ---")
+		return box.Render("\n --- " + icon.Error + " Error get file info ---")
 	}
+	
+	ext := filepath.Ext(itemPath)
+	// check if the file is pdf file, cuz pdf will cause error
+	if ext == ".pdf" {
+		return box.Render("\n --- " + icon.Error + " Unsupported  formats ---")
+	}	
+
 	if fileInfo.IsDir() {
 		directoryContent := ""
 		dirPath := itemPath
@@ -508,7 +527,7 @@ func filePreviewPanelRender(m model) string {
 		files, err := os.ReadDir(dirPath)
 		if err != nil {
 			outPutLog("Error render directory preview", err)
-			return box.Render("\n ---  Error render directory preview ---")
+			return box.Render("\n --- " + icon.Error + " Error render directory preview ---")
 		}
 
 		if len(files) == 0 {
@@ -527,7 +546,7 @@ func filePreviewPanelRender(m model) string {
 
 		for i := 0; i < previewLine && i < len(files); i++ {
 			file := files[i]
-			directoryContent += prettierDirectoryPreviewName(file.Name(), file.IsDir(), lipgloss.Color(theme.FilePanelBG))
+			directoryContent += prettierDirectoryPreviewName(file.Name(), file.IsDir(), filePanelBGColor)
 			if i != previewLine-1 && i != len(files)-1 {
 				directoryContent += "\n"
 			}
@@ -539,12 +558,12 @@ func filePreviewPanelRender(m model) string {
 	if isImageFile(itemPath) {
 		ansiRender, err := filepreview.ImagePreview(itemPath, m.fileModel.filePreview.width, previewLine, theme.FilePanelBG)
 		if err == image.ErrFormat {
-			return box.Render("\n ---  Unsupported image formats ---")
+			return box.Render("\n --- " + icon.Error + " Unsupported image formats ---")
 		}
 
 		if err != nil {
 			outPutLog("Error covernt image to ansi", err)
-			return box.Render("\n ---  Error covernt image to ansi ---")
+			return box.Render("\n --- " + icon.Error + " Error covernt image to ansi ---")
 		}
 
 		return box.AlignVertical(lipgloss.Center).AlignHorizontal(lipgloss.Center).Render(ansiRender)
@@ -552,16 +571,47 @@ func filePreviewPanelRender(m model) string {
 
 	format := lexers.Match(filepath.Base(itemPath))
 	if format != nil {
-		codeHighlight, err := ansichroma.HighlightFromFile(itemPath, previewLine, theme.CodeSyntaxHighlightTheme, theme.FilePanelBG)
+		var codeHighlight string
+		var err error
+		var fileContent string
+		file, err := os.Open(itemPath)
+		if err != nil {
+			outPutLog(err)
+			return box.Render("\n --- " + icon.Error + " Error open file ---")
+		}
+		defer file.Close()
 
+		scanner := bufio.NewScanner(file)
+		lineCount := 0
+
+		maxLineLength := m.fileModel.width + 20
+		for scanner.Scan() {
+			line := scanner.Text()
+			if len(line) > maxLineLength {
+				line = line[:maxLineLength]
+			}
+			fileContent += line + "\n"
+			lineCount++
+			if previewLine > 0 && lineCount >= previewLine {
+				break
+			}
+		}
+
+		if Config.TransparentBackground {
+			codeHighlight, err = ansichroma.HightlightString(fileContent, format.Config().Name, theme.CodeSyntaxHighlightTheme, "")
+		} else {
+			codeHighlight, err = ansichroma.HightlightString(fileContent, format.Config().Name, theme.CodeSyntaxHighlightTheme, theme.FilePanelBG)
+		}
 		if err != nil {
 			outPutLog("Error render code highlight", err)
-			return box.Render("\n ---  Error render code highlight ---")
+			return box.Render("\n --- " + icon.Error + " Error render code highlight ---")
 		}
 		if codeHighlight == "" {
 			return box.Render("\n --- empty ---")
 		}
+
 		codeHighlight = checkAndTruncateLineLengths(codeHighlight, m.fileModel.filePreview.width)
+
 		return box.Render(codeHighlight)
 	} else {
 		textFile, err := isTextFile(itemPath)
@@ -573,7 +623,7 @@ func filePreviewPanelRender(m model) string {
 			file, err := os.Open(itemPath)
 			if err != nil {
 				outPutLog(err)
-				return box.Render("\n ---  Error open file ---")
+				return box.Render("\n --- " + icon.Error + " Error open file ---")
 			}
 			defer file.Close()
 
@@ -590,14 +640,18 @@ func filePreviewPanelRender(m model) string {
 
 			if err := scanner.Err(); err != nil {
 				outPutLog(err)
-				return box.Render("\n ---  Error open file ---")
+				return box.Render("\n --- " + icon.Error + " Error open file ---")
 			}
 
-			textContent := checkAndTruncateLineLengths(string(fileContent), m.fileModel.filePreview.width)
+			textContent := checkAndTruncateLineLengths(fileContent, m.fileModel.filePreview.width)
 
 			return box.Render(textContent)
 		}
 	}
 
-	return box.Render("\n ---  Unsupported formats ---")
+	return box.Render("\n --- " + icon.Error + " Unsupported formats ---")
+}
+
+func (m model) commandLineInputBoxRender() string {
+	return m.commandLine.input.View()
 }
