@@ -65,7 +65,7 @@ const (
 )
 
 const (
-	snedWarnModal channelMessageType = iota 
+	snedWarnModal channelMessageType = iota
 	sendMetadata
 	sendProcess
 )
@@ -81,9 +81,10 @@ type model struct {
 	warnModal           warnModal
 	helpMenu            helpMenuModal
 	fileMetaData        fileMetadata
+	commandLine         commandLineModal
+	confirmToQuit 		bool
 	firstTextInput      bool
 	toggleDotFile       bool
-	editorMode          bool
 	filePanelFocusIndex int
 	mainPanelHeight     int
 	fullWidth           int
@@ -91,6 +92,10 @@ type model struct {
 }
 
 // Modal
+type commandLineModal struct {
+	input         textinput.Model
+}
+
 type helpMenuModal struct {
 	height      int
 	width       int
@@ -128,8 +133,8 @@ type fileMetadata struct {
 
 // Copied items
 type copyItems struct {
-	items         []string
-	cut           bool
+	items []string
+	cut   bool
 }
 
 /* FILE WINDOWS TYPE START*/
@@ -139,11 +144,11 @@ type fileModel struct {
 	width        int
 	renaming     bool
 	maxFilePanel int
-	filePreview filePreviewPanel
+	filePreview  filePreviewPanel
 }
 
 type filePreviewPanel struct {
-	open bool
+	open  bool
 	width int
 }
 
@@ -185,7 +190,7 @@ type element struct {
 type sidebarModel struct {
 	directories []directory
 	renderIndex int
-	cursor int
+	cursor      int
 }
 
 type directory struct {
@@ -218,7 +223,7 @@ type process struct {
 // Message for process bar
 type channelMessage struct {
 	messageId       string
-	messageType 	channelMessageType
+	messageType     channelMessageType
 	processNewState process
 	warnModal       warnModal
 	metadata        [][2]string
@@ -226,10 +231,4 @@ type channelMessage struct {
 
 /*PROCESS BAR internal TYPE END*/
 
-// Style for icons
-type iconStyle struct {
-	icon  string
-	color string
-}
-
 type editorFinishedMsg struct{ err error }
